@@ -51,6 +51,8 @@ class TestClient(asynctest.TestCase):
     _delete_email_id = None
     _refresh_token = None
     _domain_id = None
+    _service_principle_id=None
+    _should_exist_app_id = None
 
     def setUp(self):
         pass
@@ -94,6 +96,7 @@ class TestClient(asynctest.TestCase):
         cls._refresh_token = details["refresh_token"]
         cls._single_user_app_id = details["single_user_app_id"]
         cls._single_user_app_secret = details["single_user_app_secret"]
+        cls._should_exist_app_id = details["should_exist_app_id"]
 
         token_params = {
             'grant_type': 'client_credentials',
@@ -830,3 +833,22 @@ class TestClient(asynctest.TestCase):
         i = self.get_instance()
         res, status = await i.get_domain(TestClient._domain_id, token=TestClient._token)
         self.assertEqual(status, HTTPStatus.OK)
+
+    async def test_list_service_principles(self):
+        i = self.get_instance()
+        res, status = await i.list_service_principles(token=TestClient._token)
+        self.assertEqual(status, HTTPStatus.OK)
+
+    async def test_get_service_principle(self):
+        i = self.get_instance()
+        res, status = await i.get_service_principle(TestClient._service_principle_id, token=TestClient._token)
+        self.assertEqual(status, HTTPStatus.OK)
+
+    async def test_get_service_principle_with_filter(self):
+        i = self.get_instance()
+        odata_query = ODataQuery()
+        odata_query.filter = Filter([Constrain("appId", LogicalOperator.EQ, TestClient._should_exist_app_id)])
+        res, status = await i.get_service_principle(TestClient._service_principle_id, token=TestClient._token,
+                                                    odata_query=odata_query)
+        self.assertEqual(status, HTTPStatus.OK)
+        self.assertEqual(len(res['value']), 1)
