@@ -18,6 +18,12 @@ class LogicalOperator(int, Enum):
     GE = 6, "{attribute} ge {val}"
     STARTS_WITH = 7, "startswith({attribute}, '{val}')"
     ENDS_WITH = 8, "endswith({attribute}, '{val}')"
+    ANY_EQ = 9, "{attribute}/any(f:f/{inner_attribute} eq '{val}')"
+
+
+class Order(int, Enum):
+    asc = 1
+    desc = 2
 
 
 class LogicalConnector(int, Enum):
@@ -34,10 +40,11 @@ class Constrain:
     Constrain example for O365 message resource which has the attribute subject equals to "Trip Ahead" will be instanced
     like this: c = Constrain("subject", LogicalOperator.EQ, "Trip Ahead"
     """
-    def __init__(self, attribute: str, logical_operator: LogicalOperator, value: str):
+    def __init__(self, attribute: str, logical_operator: LogicalOperator, value: str, inner_attribute: str = None):
         self.attribute = attribute
         self.logical_operator = logical_operator
         self.value = value
+        self.inner_attribute = inner_attribute
 
     @property
     def attribute(self) -> str:
@@ -69,8 +76,19 @@ class Constrain:
             raise ValueError("value must be str")
         self._value = val
 
+    @property
+    def inner_attribute(self) -> str:
+        return self._inner_attribute
+
+    @inner_attribute.setter
+    def inner_attribute(self, val: str):
+        if val and type(val) != str:
+            raise ValueError("inner attribute must be str")
+        self._inner_attribute = val
+
     def __str__(self):
-        return self._logical_operator.template.format(attribute=self._attribute, val=self._value)
+        return self._logical_operator.template.format(attribute=self._attribute, val=self._value,
+                                                      inner_attribute=self._inner_attribute)
 
 
 class Filter:
@@ -107,6 +125,35 @@ class Filter:
         self._logical_connector = value
 
 
+class OrderBy:
+    def __init__(self, attribute, order):
+        self.attribute = attribute
+        self.order = order
+
+    @property
+    def attribute(self) -> str:
+        return self._attribute
+
+    @attribute.setter
+    def attribute(self, value: str):
+        if type(value) is not str:
+            raise ValueError("attribute must be string")
+        self._attribute = value
+
+    @property
+    def order(self) -> Order:
+        return self._order
+
+    @order.setter
+    def order(self, value: Order):
+        if type(value) is not Order:
+            raise ValueError("order must be of type Order")
+        self._order = value
+
+    def __str__(self):
+        return f"{self.attribute} {self.order.name}"
+
+
 class ODataQuery:
     def __init__(self):
         self._count = None
@@ -114,6 +161,7 @@ class ODataQuery:
         self._filter = None
         self._select = None
         self._top = None
+        self._order_by = None
 
     @property
     def count(self) -> bool:
@@ -173,6 +221,17 @@ class ODataQuery:
             raise ValueError("top must be integer")
         self._top = value
 
+    @property
+    def order_by(self) -> int:
+        """Sets the field that will determine the order and the direction."""
+        return self._order_by
+
+    @order_by.setter
+    def order_by(self, value: OrderBy):
+        if type(value) is not OrderBy:
+            raise ValueError("order_by must be OrderBy")
+        self._order_by = value
+
     def _build_filter(self):
         res = ""
         for constrain in self.filter.constrains:  # type: Constrain
@@ -195,5 +254,7 @@ class ODataQuery:
             res.append(f"$select={','.join(self.select)}")
         if self.top:
             res.append(f"$top={str(self.top)}")
+        if self.order_by:
+            res.append(f"$orderby={str(self.order_by)}")
 
         return f"?{'&'.join(res)}"
